==> ider_login-7.x-1.4.zip: ider_login/readme.md <==
# Drupal 7.x IDer login

This plugin provides functionality to register and connect to your WordPress via IDer Service.

# How it works?
  1. First of all you need to create a profile in the [IDer](https://ider.com) website.
  2. Clicking the button a redirect to the IDer server will display a QR Code.
  3. To scan it you need to download the free IDer App from the App Store or Google Play depending which smartphone you own. Or just scan the QR code with any QR Code reader and you will be redirect to the download page. Provide few infos and you are ready to scan the QR code.
  4. After that the IDer App will prompt you for the missing data required to complete the login/registration process. Confirming the data your browser will automatically log you in and show you which info the website saved.

# Installation

1. Download the module files, and trough the admin dashboard upload the files into your Drupal 7 installation.
2. Enable the module through the 'Modules' page in Drupal 7.
3. Go to the IDer Login configuration page.
4. Configure the plugin as descripted. You need to create a profile in the [IDer](https://ider.com).
5. With the data collected during the profile creation process fill in the Client ID, Client Secret and Campaign ID fields.
6. Change the other settings if you want like button CSS etc...

# Frequently Asked Questions

* Where can I download the App?
    *  You can find the IDer app in your App Store or Google Play. Search for "ider".
* Can I hack/improve/fork/edit this plugin?
    *  Mmmm. Even though we encourage the developing and extension of new plugins it doesn't sound like a good idea in this case. This plugin has been very tested and stressed and it should be use as it is. But if you got a brilliant idea or suggestion we would love to hear from you.

==> ider_login-7.x-1.5.zip: ider_login/readme.md <==
# Drupal 7.x IDer login

This plugin provides functionality to register and connect to your Drupal 7 via IDer Service.

# How it works?
  1. First of all you need to create a profile in the [IDer](https://ider.com) website.
  2. Clicking the button a redirect to the IDer server will display a QR Code.
  3. To scan it you need to download the free IDer App from the App Store or Google Play depending which smartphone you own. Or just scan the QR code with any QR Code reader and you will be redirect to the download page. Provide few infos and you are ready to scan the QR code.
  4. After that the IDer App will prompt you for the missing data required to complete the login/registration process. Confirming the data your browser will automatically log you in and show you which info the website saved.

# Installation

1. Download the module files, and trough the admin dashboard upload the files into your Drupal 7 installation.
2. Enable the module through the 'Modules' page in Drupal 7.
3. Go to the IDer Login configuration page.
4. Configure the plugin as descripted. You need to create a profile in the [IDer](https://ider.com).
5. With the data collected during the profile creation process fill in the Client ID, Client Secret and Campaign ID fields.
6. Change the other settings if you want like button CSS etc...

# Frequently Asked Questions

* Where can I download the App?
    *  You can find the IDer app in your App Store or Google Play. Search for "ider".
* Can I hack/improve/fork/edit this plugin?
    *  Mmmm. Even though we encourage the developing and extension of new plugins it doesn't sound like a good idea in this case. This plugin has been very tested and stressed and it should be use as it is. But if you got a brilliant idea or suggestion we would love to hear from you.
